@@ -1,3 +1,4 @@
+from copy import copy
 from itertools import repeat
 from typing import List, NamedTuple, Optional, Sequence, Union
 
@@ -78,7 +79,7 @@ class FCMDeviceQuerySet(models.query.QuerySet):
     @staticmethod
     def _prepare_message(message: messaging.Message, token: str):
         message.token = token
-        return message
+        return copy(message)
 
     @staticmethod
     def get_default_send_message_response() -> FirebaseResponseDict:
@@ -261,7 +262,7 @@ class AbstractFCMDevice(Device):
         null=True,
         db_index=True,
         help_text=_("Unique device identifier"),
-        max_length=150,
+        max_length=3072,
     )
     registration_id = models.TextField(verbose_name=_("Registration token"))
     type = models.CharField(choices=DEVICE_TYPES, max_length=10)
